tuplettools.scale_contents_of_tuplets_in_expr_by_multiplier
===========================================================

.. autofunction:: abjad.tools.tuplettools.scale_contents_of_tuplets_in_expr_by_multiplier.scale_contents_of_tuplets_in_expr_by_multiplier
